!!! warning
    This page is under construction. The content may be incomplete or incorrect. Submit an issue
    on [GitHub](https://github.com/QuEraComputing/kirin/issues/new) if you need help or want to
    contribute.

# Core Python Dialects

This page contains the core Python dialects that are used most frequently when designing an
embedded DSL in Python.

## Reference

### Base

::: kirin.dialects.py.base
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true

### Constant

::: kirin.dialects.py.constant
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true

### UnaryOp

::: kirin.dialects.py.unary.stmts
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true


### BinOp

::: kirin.dialects.py.binop.stmts
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true

### Assertion

::: kirin.dialects.py.assertion
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true

### Assignment

::: kirin.dialects.py.assign
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true


### Unpack

::: kirin.dialects.py.unpack
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true


### Boolean Operation

::: kirin.dialects.py.boolop
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true

### Comparison

::: kirin.dialects.py.cmp.stmts
    options:
        filters:
        - "!statement"
        show_root_heading: true
        show_if_no_docstring: true
